@@ -42,11 +42,11 @@ from urlparse import urljoin, urlunparse, ParseResult
 __all__ = ['WeedMaster']
 
 
-
+import time
 import json
 import urlparse
 import requests
-from conf import LOGGER
+from conf import *
 from util import *
 
 from volume import WeedVolume
@@ -74,6 +74,9 @@ class WeedMaster(object):
         self.url_vacuum = urljoin(self.url_base, '/vol/vacuum')
         self.url_status = urljoin(self.url_base, '/dir/status')
 
+        # volumes usually do not move, so we cache it here for 1 minute.
+        self.volumes_cache = {}
+
 
     def acquire_assign_info(self):
         """
@@ -139,10 +142,10 @@ class WeedMaster(object):
         return wak
 
 
-    def lookup(self, volume_id):
+    def lookup(self, volume_id_or_fid, cache_duration_in_seconds=VOLUME_CACHE_DURATION_IN_SECONDS):
         """
-        lookup the urls of a volume
-        return a dict like below if successful else None:
+        lookup the locations of a volume@volume_id_or_fid.
+        returns a dict like below if successful else None:
         -----------
         {
           "locations": [
@@ -157,10 +160,25 @@ class WeedMaster(object):
         Arguments:
         - `self`:
         """
+        if ',' in volume_id_or_fid:
+            _volume_id = volume_id_or_fid.split(',')[0]
+        elif '/' in volume_id_or_fid:
+            _volume_id = volume_id_or_fid.split('/')[0]
+        else:
+            _volume_id = volume_id_or_fid
         result = None
         try:
-            r = requests.get(self.url_lookup + '?volumeId=%s' % volume_id)
-            result = json.loads(r.content)
+            ## try cache first
+            if self.volumes_cache.has_key(_volume_id) and (time.time() - self.volumes_cache[_volume_id][1]) <= cache_duration_in_seconds:
+                LOGGER.debug('volume_cache(lookup by volume_id) hits')
+                return self.volumes_cache[_volume_id][0]
+            else:
+                r = requests.get(self.url_lookup + '?volumeId=%s' % _volume_id)
+                result = json.loads(r.content)
+
+                ## refresh cache
+                self.volumes_cache.update({_volume_id : (result, time.time())})
+
         except Exception as e:
             LOGGER.error("Could not get status of this volume: %s. "
                 "Exception is: %s" % (self.url_status, e))
